@@ -29,8 +29,6 @@ from math import sqrt
 import os
 import sys
 
-Clutter.init("antler")
-
 
 class AnimatedWindowBase(Gtk.Window, Clutter.Animatable):
     __gproperties__ = {
@@ -56,7 +54,7 @@ class AnimatedWindowBase(Gtk.Window, Clutter.Animatable):
         elif property.name == "antler-window-y":
             return self.get_position()[1]
         else:
-            raise AttributeError, 'unknown property %s' % property.name
+            raise AttributeError('unknown property %s' % property.name)
 
     def do_set_property(self, property, value):
         if property.name == "antler-window-x":
@@ -66,7 +64,7 @@ class AnimatedWindowBase(Gtk.Window, Clutter.Animatable):
             if value is not None:
                 self.move(self.get_position()[0], value)
         else:
-            raise AttributeError, 'unknown property %s' % property.name
+            raise AttributeError('unknown property %s' % property.name)
 
     def do_animate_property(self, animation, prop_name, initial_value,
                             final_value, progress, gvalue):
@@ -220,7 +218,7 @@ class AntlerWindow(ProximityWindowBase):
         self.add(self._vbox)
 
         self.keyboard_view_factory = keyboard_view_factory
-        self.keyboard_view = keyboard_view_factory (settings.keyboard_type.value)
+        self.keyboard_view = keyboard_view_factory (keyboard_type=settings.keyboard_type.value)
 
         self._vbox.pack_start(self.keyboard_view, True, True, 0)
 
